# seres-client
API for the Seres core platform

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 0.0.1
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import seres_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import seres_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import seres_client
from seres_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = seres_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIKeyHeader
configuration.api_key['APIKeyHeader'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyHeader'] = 'Bearer'

# Configure API key authorization: APIKeyCookie
configuration.api_key['APIKeyCookie'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyCookie'] = 'Bearer'


# Enter a context with an instance of the API client
with seres_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = seres_client.AccessKeysApi(api_client)
    access_key_creation_schema = seres_client.AccessKeyCreationSchema() # AccessKeyCreationSchema | 

    try:
        # Create Access Key
        api_response = api_instance.create_access_key(access_key_creation_schema)
        print("The response of AccessKeysApi->create_access_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccessKeysApi->create_access_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccessKeysApi* | [**create_access_key**](docs/AccessKeysApi.md#create_access_key) | **POST** /api/access-keys | Create Access Key
*AccessKeysApi* | [**disable_access_key**](docs/AccessKeysApi.md#disable_access_key) | **POST** /api/access-keys/{access_key_id}/disable | Disable Access Key
*AccessKeysApi* | [**get_access_key**](docs/AccessKeysApi.md#get_access_key) | **GET** /api/access-keys/{access_key_id} | Get Access Key
*AccessKeysApi* | [**get_access_key_me**](docs/AccessKeysApi.md#get_access_key_me) | **GET** /api/access-keys/me | Get Access Key Me
*AccessKeysApi* | [**get_access_keys**](docs/AccessKeysApi.md#get_access_keys) | **GET** /api/access-keys | Get Access Keys
*AccessKeysApi* | [**reactivate_access_key**](docs/AccessKeysApi.md#reactivate_access_key) | **POST** /api/access-keys/{access_key_id}/reactivate | Reactivate Access Key
*AuthenticationApi* | [**login**](docs/AuthenticationApi.md#login) | **POST** /api/login | Login
*AuthenticationApi* | [**logout**](docs/AuthenticationApi.md#logout) | **POST** /api/logout | Logout
*AvailableResourceAssembliesApi* | [**get_available_assemblies**](docs/AvailableResourceAssembliesApi.md#get_available_assemblies) | **GET** /api/available-resource-assemblies | Get Available Assemblies
*FlightPlanCreationRequestsApi* | [**create_flight_plan_creation_request**](docs/FlightPlanCreationRequestsApi.md#create_flight_plan_creation_request) | **POST** /api/flight-plan-creation-requests | Create Flight Plan Creation Request
*FlightPlanCreationRequestsApi* | [**get_flight_plan_creation_request**](docs/FlightPlanCreationRequestsApi.md#get_flight_plan_creation_request) | **GET** /api/flight-plan-creation-requests/{request_id} | Get Flight Plan Creation Request
*FlightPlanCreationRequestsApi* | [**get_flight_plan_creation_requests**](docs/FlightPlanCreationRequestsApi.md#get_flight_plan_creation_requests) | **GET** /api/flight-plan-creation-requests | Get Flight Plan Creation Requests
*FlightPlanLegResourcesApi* | [**cancel_flight_plan_leg_resource**](docs/FlightPlanLegResourcesApi.md#cancel_flight_plan_leg_resource) | **DELETE** /api/flight-plan-leg-resources/{leg_resource_id} | Cancel Flight Plan Leg Resource
*FlightPlanLegResourcesApi* | [**create_flight_plan_leg_resource**](docs/FlightPlanLegResourcesApi.md#create_flight_plan_leg_resource) | **POST** /api/flight-plan-leg-resources | Create Flight Plan Leg Resource
*FlightPlanLegsApi* | [**cancel_flight_plan_leg**](docs/FlightPlanLegsApi.md#cancel_flight_plan_leg) | **DELETE** /api/flight-plan-legs/{flight_plan_leg_id} | Cancel Flight Plan Leg
*FlightPlanLegsApi* | [**create_flight_plan_leg**](docs/FlightPlanLegsApi.md#create_flight_plan_leg) | **POST** /api/flight-plan-legs | Create Flight Plan Leg
*FlightPlanReferencesApi* | [**get_flight_plan_reference**](docs/FlightPlanReferencesApi.md#get_flight_plan_reference) | **GET** /api/flight-plan-references/{flight_plan_id} | Get Flight Plan Reference
*FlightPlanReferencesApi* | [**get_flight_plan_references**](docs/FlightPlanReferencesApi.md#get_flight_plan_references) | **GET** /api/flight-plan-references | Get Flight Plan References
*FlightPlanSchemaLegsApi* | [**create_flight_plan_schema_leg**](docs/FlightPlanSchemaLegsApi.md#create_flight_plan_schema_leg) | **POST** /api/flight-plan-schema-legs | Create Flight Plan Schema Leg
*FlightPlanSchemaLegsApi* | [**delete_flight_plan_schema_leg**](docs/FlightPlanSchemaLegsApi.md#delete_flight_plan_schema_leg) | **DELETE** /api/flight-plan-schema-legs/{flight_plan_schema_leg_id} | Delete Flight Plan Schema Leg
*FlightPlanSchemaLegsApi* | [**get_flight_plan_schema_leg**](docs/FlightPlanSchemaLegsApi.md#get_flight_plan_schema_leg) | **GET** /api/flight-plan-schema-legs/{flight_plan_schema_leg_id} | Get Flight Plan Schema Leg
*FlightPlanSchemaLegsApi* | [**get_flight_plan_schema_legs**](docs/FlightPlanSchemaLegsApi.md#get_flight_plan_schema_legs) | **GET** /api/flight-plan-schema-legs | Get Flight Plan Schema Legs
*FlightPlanSchemaLegsApi* | [**update_flight_plan_schema_leg**](docs/FlightPlanSchemaLegsApi.md#update_flight_plan_schema_leg) | **PATCH** /api/flight-plan-schema-legs/{flight_plan_schema_leg_id} | Update Flight Plan Schema Leg
*FlightPlanSchemaWaypointsApi* | [**create_flight_plan_schema_waypoint**](docs/FlightPlanSchemaWaypointsApi.md#create_flight_plan_schema_waypoint) | **POST** /api/flight-plan-schema-waypoints | Create Flight Plan Schema Waypoint
*FlightPlanSchemaWaypointsApi* | [**delete_flight_plan_schema_waypoint**](docs/FlightPlanSchemaWaypointsApi.md#delete_flight_plan_schema_waypoint) | **DELETE** /api/flight-plan-schema-waypoints/{flight_plan_schema_waypoint_id} | Delete Flight Plan Schema Waypoint
*FlightPlanSchemaWaypointsApi* | [**get_flight_plan_schema_waypoint**](docs/FlightPlanSchemaWaypointsApi.md#get_flight_plan_schema_waypoint) | **GET** /api/flight-plan-schema-waypoints/{flight_plan_schema_waypoint_id} | Get Flight Plan Schema Waypoint
*FlightPlanSchemaWaypointsApi* | [**get_flight_plan_schema_waypoints**](docs/FlightPlanSchemaWaypointsApi.md#get_flight_plan_schema_waypoints) | **GET** /api/flight-plan-schema-waypoints | Get Flight Plan Schema Waypoints
*FlightPlanSchemaWaypointsApi* | [**update_flight_plan_schema_waypoint**](docs/FlightPlanSchemaWaypointsApi.md#update_flight_plan_schema_waypoint) | **PATCH** /api/flight-plan-schema-waypoints/{flight_plan_schema_waypoint_id} | Update Flight Plan Schema Waypoint
*FlightPlanSchemasApi* | [**activate_flight_plan_schema**](docs/FlightPlanSchemasApi.md#activate_flight_plan_schema) | **POST** /api/flight-plan-schemas/{flight_plan_schema_id}/activate | Activate Flight Plan Schema
*FlightPlanSchemasApi* | [**create_flight_plan_schema**](docs/FlightPlanSchemasApi.md#create_flight_plan_schema) | **POST** /api/flight-plan-schemas | Create Flight Plan Schema
*FlightPlanSchemasApi* | [**create_flight_plan_schema_revision**](docs/FlightPlanSchemasApi.md#create_flight_plan_schema_revision) | **POST** /api/flight-plan-schemas/{flight_plan_schema_id}/revision | Create Flight Plan Schema Revision
*FlightPlanSchemasApi* | [**create_flight_plan_schema_variation**](docs/FlightPlanSchemasApi.md#create_flight_plan_schema_variation) | **POST** /api/flight-plan-schemas/{flight_plan_schema_id}/variation | Create Flight Plan Schema Variation
*FlightPlanSchemasApi* | [**decommission_flight_plan_schema**](docs/FlightPlanSchemasApi.md#decommission_flight_plan_schema) | **POST** /api/flight-plan-schemas/{flight_plan_schema_id}/decommission | Decommission Flight Plan Schema
*FlightPlanSchemasApi* | [**delete_flight_plan_schema**](docs/FlightPlanSchemasApi.md#delete_flight_plan_schema) | **DELETE** /api/flight-plan-schemas/{flight_plan_schema_id} | Delete Flight Plan Schema
*FlightPlanSchemasApi* | [**get_flight_plan_schema**](docs/FlightPlanSchemasApi.md#get_flight_plan_schema) | **GET** /api/flight-plan-schemas/{flight_plan_schema_id} | Get Flight Plan Schema
*FlightPlanSchemasApi* | [**get_flight_plan_schemas**](docs/FlightPlanSchemasApi.md#get_flight_plan_schemas) | **GET** /api/flight-plan-schemas | Get Flight Plan Schemas
*FlightPlanSchemasApi* | [**update_flight_plan_schema**](docs/FlightPlanSchemasApi.md#update_flight_plan_schema) | **PATCH** /api/flight-plan-schemas/{flight_plan_schema_id} | Update Flight Plan Schema
*FlightPlanWaypointsApi* | [**cancel_flight_plan_waypoint**](docs/FlightPlanWaypointsApi.md#cancel_flight_plan_waypoint) | **DELETE** /api/flight-plan-waypoints/{flight_plan_waypoint_id} | Cancel Flight Plan Waypoint
*FlightPlanWaypointsApi* | [**create_flight_plan_waypoint**](docs/FlightPlanWaypointsApi.md#create_flight_plan_waypoint) | **POST** /api/flight-plan-waypoints | Create Flight Plan Waypoint
*FlightPlansApi* | [**create_flight_plan**](docs/FlightPlansApi.md#create_flight_plan) | **POST** /api/flight-plans | Create Flight Plan
*FlightPlansApi* | [**delete_flight_plan**](docs/FlightPlansApi.md#delete_flight_plan) | **DELETE** /api/flight-plans/{flight_plan_id} | Delete Flight Plan
*FlightPlansApi* | [**get_flight_plan**](docs/FlightPlansApi.md#get_flight_plan) | **GET** /api/flight-plans/{flight_plan_id} | Get Flight Plan
*FlightPlansApi* | [**get_flight_plans**](docs/FlightPlansApi.md#get_flight_plans) | **GET** /api/flight-plans | Get Flight Plans
*FutureActivitiesApi* | [**get_future_activities**](docs/FutureActivitiesApi.md#get_future_activities) | **GET** /api/future-activities | Get Future Activities
*FuturesApi* | [**commit_future**](docs/FuturesApi.md#commit_future) | **POST** /api/futures/{future_id}/commit | Commit Future
*FuturesApi* | [**create_future**](docs/FuturesApi.md#create_future) | **POST** /api/futures | Create Future
*FuturesApi* | [**delete_future**](docs/FuturesApi.md#delete_future) | **DELETE** /api/futures/{future_id} | Delete Future
*FuturesApi* | [**get_future**](docs/FuturesApi.md#get_future) | **GET** /api/futures/{future_id} | Get Future
*FuturesApi* | [**get_futures**](docs/FuturesApi.md#get_futures) | **GET** /api/futures | Get Futures
*FuturesApi* | [**verify_future**](docs/FuturesApi.md#verify_future) | **GET** /api/futures/{future_id}/verify | Verify Future
*PadWindowsApi* | [**get_pad_window**](docs/PadWindowsApi.md#get_pad_window) | **GET** /api/pad-windows/{window_id} | Get Pad Window
*PadWindowsApi* | [**get_pad_windows**](docs/PadWindowsApi.md#get_pad_windows) | **GET** /api/pad-windows | Get Pad Windows
*PortsApi* | [**get_port**](docs/PortsApi.md#get_port) | **GET** /api/ports/{port_id} | Get Port
*PortsApi* | [**get_ports**](docs/PortsApi.md#get_ports) | **GET** /api/ports | Get Ports
*ResourceAssemblySchemaEnergyBankComponentsApi* | [**get_resource_assembly_schema_energy_bank_component**](docs/ResourceAssemblySchemaEnergyBankComponentsApi.md#get_resource_assembly_schema_energy_bank_component) | **GET** /api/resource-assembly-schema-energy-bank-components/{energy_bank_component_id} | Get Resource Assembly Schema Energy Bank Component
*ResourceAssemblySchemaEnergyBankComponentsApi* | [**get_resource_assembly_schema_energy_bank_components**](docs/ResourceAssemblySchemaEnergyBankComponentsApi.md#get_resource_assembly_schema_energy_bank_components) | **GET** /api/resource-assembly-schema-energy-bank-components | Get Resource Assembly Schema Energy Bank Components
*ResourceAssemblySchemaEnergyBankConsumersApi* | [**get_resource_assembly_schema_energy_bank_consumer**](docs/ResourceAssemblySchemaEnergyBankConsumersApi.md#get_resource_assembly_schema_energy_bank_consumer) | **GET** /api/resource-assembly-schema-energy-bank-consumers/{energy_bank_consumer_id} | Get Resource Assembly Schema Energy Bank Consumer
*ResourceAssemblySchemaEnergyBankConsumersApi* | [**get_resource_assembly_schema_energy_bank_consumers**](docs/ResourceAssemblySchemaEnergyBankConsumersApi.md#get_resource_assembly_schema_energy_bank_consumers) | **GET** /api/resource-assembly-schema-energy-bank-consumers | Get Resource Assembly Schema Energy Bank Consumers
*ResourceAssemblySchemaEnergyBanksApi* | [**get_resource_assembly_schema_energy_bank**](docs/ResourceAssemblySchemaEnergyBanksApi.md#get_resource_assembly_schema_energy_bank) | **GET** /api/resource-assembly-schema-energy-banks/{energy_bank_id} | Get Resource Assembly Schema Energy Bank
*ResourceAssemblySchemaEnergyBanksApi* | [**get_resource_assembly_schema_energy_banks**](docs/ResourceAssemblySchemaEnergyBanksApi.md#get_resource_assembly_schema_energy_banks) | **GET** /api/resource-assembly-schema-energy-banks | Get Resource Assembly Schema Energy Banks
*ResourceAssemblySchemaRefuelSwapsApi* | [**get_resource_assembly_schema_refuel_swap**](docs/ResourceAssemblySchemaRefuelSwapsApi.md#get_resource_assembly_schema_refuel_swap) | **GET** /api/resource-assembly-schema-refuel-swaps/{swap_id} | Get Resource Assembly Schema Refuel Swap
*ResourceAssemblySchemaRefuelSwapsApi* | [**get_resource_assembly_schema_refuel_swaps**](docs/ResourceAssemblySchemaRefuelSwapsApi.md#get_resource_assembly_schema_refuel_swaps) | **GET** /api/resource-assembly-schema-refuel-swaps | Get Resource Assembly Schema Refuel Swaps
*ResourceAssemblySchemasApi* | [**get_resource_assembly_schema**](docs/ResourceAssemblySchemasApi.md#get_resource_assembly_schema) | **GET** /api/resource-assembly-schemas/{resource_assembly_schema_id} | Get Resource Assembly Schema
*ResourceAssemblySchemasApi* | [**get_resource_assembly_schemas**](docs/ResourceAssemblySchemasApi.md#get_resource_assembly_schemas) | **GET** /api/resource-assembly-schemas | Get Resource Assembly Schemas
*ResourceSchemaActionSchemasApi* | [**get_resource_schema_action_schema**](docs/ResourceSchemaActionSchemasApi.md#get_resource_schema_action_schema) | **GET** /api/resource-schema-action-schemas/{resource_schema_action_schema_id} | Get Resource Schema Action Schema
*ResourceSchemaActionSchemasApi* | [**get_resource_schema_action_schemas**](docs/ResourceSchemaActionSchemasApi.md#get_resource_schema_action_schemas) | **GET** /api/resource-schema-action-schemas | Get Resource Schema Action Schemas
*ResourceSchemaActionsApi* | [**get_resource_schema_action**](docs/ResourceSchemaActionsApi.md#get_resource_schema_action) | **GET** /api/resource-schema-actions/{resource_schema_action_id} | Get Resource Schema Action
*ResourceSchemaActionsApi* | [**get_resource_schema_actions**](docs/ResourceSchemaActionsApi.md#get_resource_schema_actions) | **GET** /api/resource-schema-actions | Get Resource Schema Actions
*ResourceSchemasApi* | [**get_resource_schema**](docs/ResourceSchemasApi.md#get_resource_schema) | **GET** /api/resource-schemas/{resource_schema_id} | Get Resource Schema
*ResourceSchemasApi* | [**get_resource_schema_preview**](docs/ResourceSchemasApi.md#get_resource_schema_preview) | **GET** /api/resource-schemas/{resource_schema_id}/preview.glb | Get Resource Schema Preview
*ResourceSchemasApi* | [**get_resource_schemas**](docs/ResourceSchemasApi.md#get_resource_schemas) | **GET** /api/resource-schemas | Get Resource Schemas
*ResourcesApi* | [**get_resource**](docs/ResourcesApi.md#get_resource) | **GET** /api/resources/{resource_id} | Get Resource
*ResourcesApi* | [**get_resources**](docs/ResourcesApi.md#get_resources) | **GET** /api/resources | Get Resources
*SubnetsApi* | [**get_subnet**](docs/SubnetsApi.md#get_subnet) | **GET** /api/subnets/{subnet_id} | Get Subnet
*SubnetsApi* | [**get_subnets**](docs/SubnetsApi.md#get_subnets) | **GET** /api/subnets | Get Subnets
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /api/users | Create User
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /api/users/{user_id} | Delete User
*UsersApi* | [**disable_user**](docs/UsersApi.md#disable_user) | **POST** /api/users/{user_id}/disable | Disable User
*UsersApi* | [**get_me**](docs/UsersApi.md#get_me) | **GET** /api/users/me | Get Me
*UsersApi* | [**get_platform_user**](docs/UsersApi.md#get_platform_user) | **GET** /api/users/{user_id} | Get Platform User
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users) | **GET** /api/users | Get Users
*UsersApi* | [**reactivate_user**](docs/UsersApi.md#reactivate_user) | **POST** /api/users/{user_id}/reactivate | Reactivate User


## Documentation For Models

 - [AccessKeyCreationSchema](docs/AccessKeyCreationSchema.md)
 - [AccessKeySchema](docs/AccessKeySchema.md)
 - [AccessKeyStatusEnum](docs/AccessKeyStatusEnum.md)
 - [Altitude](docs/Altitude.md)
 - [AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaInput](docs/AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaInput.md)
 - [AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaOutput](docs/AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaOutput.md)
 - [AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput](docs/AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput.md)
 - [AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaOutput](docs/AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaOutput.md)
 - [AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema](docs/AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema.md)
 - [AvailableResourceAssemblySchemaComponentSchema](docs/AvailableResourceAssemblySchemaComponentSchema.md)
 - [AvailableResourceAssemblySchemaSchema](docs/AvailableResourceAssemblySchemaSchema.md)
 - [AverageSpeed](docs/AverageSpeed.md)
 - [ConfigurationEnum](docs/ConfigurationEnum.md)
 - [Elevation](docs/Elevation.md)
 - [ExpectedStatus](docs/ExpectedStatus.md)
 - [FlightPlanCreationRequestCreationSchema](docs/FlightPlanCreationRequestCreationSchema.md)
 - [FlightPlanCreationRequestSchema](docs/FlightPlanCreationRequestSchema.md)
 - [FlightPlanCreationRequestStatusEnum](docs/FlightPlanCreationRequestStatusEnum.md)
 - [FlightPlanCreationSchema](docs/FlightPlanCreationSchema.md)
 - [FlightPlanLegCreationSchema](docs/FlightPlanLegCreationSchema.md)
 - [FlightPlanLegResourceCreationSchema](docs/FlightPlanLegResourceCreationSchema.md)
 - [FlightPlanLegResourceSchema](docs/FlightPlanLegResourceSchema.md)
 - [FlightPlanLegSchema](docs/FlightPlanLegSchema.md)
 - [FlightPlanReferenceSchema](docs/FlightPlanReferenceSchema.md)
 - [FlightPlanSchema](docs/FlightPlanSchema.md)
 - [FlightPlanSchemaCreationSchema](docs/FlightPlanSchemaCreationSchema.md)
 - [FlightPlanSchemaLegCreationSchema](docs/FlightPlanSchemaLegCreationSchema.md)
 - [FlightPlanSchemaLegImmediateCreationSchema](docs/FlightPlanSchemaLegImmediateCreationSchema.md)
 - [FlightPlanSchemaLegSchema](docs/FlightPlanSchemaLegSchema.md)
 - [FlightPlanSchemaLegUpdateSchema](docs/FlightPlanSchemaLegUpdateSchema.md)
 - [FlightPlanSchemaRevisionCreationSchema](docs/FlightPlanSchemaRevisionCreationSchema.md)
 - [FlightPlanSchemaSchema](docs/FlightPlanSchemaSchema.md)
 - [FlightPlanSchemaType](docs/FlightPlanSchemaType.md)
 - [FlightPlanSchemaUpdateSchema](docs/FlightPlanSchemaUpdateSchema.md)
 - [FlightPlanSchemaVariationCreationSchema](docs/FlightPlanSchemaVariationCreationSchema.md)
 - [FlightPlanSchemaWaypointCreationSchema](docs/FlightPlanSchemaWaypointCreationSchema.md)
 - [FlightPlanSchemaWaypointImmediateCreationSchema](docs/FlightPlanSchemaWaypointImmediateCreationSchema.md)
 - [FlightPlanSchemaWaypointSchema](docs/FlightPlanSchemaWaypointSchema.md)
 - [FlightPlanSchemaWaypointUpdateSchema](docs/FlightPlanSchemaWaypointUpdateSchema.md)
 - [FlightPlanTypeEnum](docs/FlightPlanTypeEnum.md)
 - [FlightPlanWaypointCreationSchema](docs/FlightPlanWaypointCreationSchema.md)
 - [FlightPlanWaypointSchema](docs/FlightPlanWaypointSchema.md)
 - [FutureActivitySchema](docs/FutureActivitySchema.md)
 - [FutureActivityType](docs/FutureActivityType.md)
 - [FutureCreationSchema](docs/FutureCreationSchema.md)
 - [FutureEntityType](docs/FutureEntityType.md)
 - [FutureSchema](docs/FutureSchema.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [ImplementationStatusEnum](docs/ImplementationStatusEnum.md)
 - [Latitude](docs/Latitude.md)
 - [LoginResponseSchema](docs/LoginResponseSchema.md)
 - [LoginSchema](docs/LoginSchema.md)
 - [Longitude](docs/Longitude.md)
 - [NewEntityIdSchema](docs/NewEntityIdSchema.md)
 - [PadWindowSchema](docs/PadWindowSchema.md)
 - [PaginatedResponseSchemaAccessKeySchema](docs/PaginatedResponseSchemaAccessKeySchema.md)
 - [PaginatedResponseSchemaFlightPlanCreationRequestSchema](docs/PaginatedResponseSchemaFlightPlanCreationRequestSchema.md)
 - [PaginatedResponseSchemaFlightPlanReferenceSchema](docs/PaginatedResponseSchemaFlightPlanReferenceSchema.md)
 - [PaginatedResponseSchemaFlightPlanSchemaSchema](docs/PaginatedResponseSchemaFlightPlanSchemaSchema.md)
 - [PaginatedResponseSchemaFutureActivitySchema](docs/PaginatedResponseSchemaFutureActivitySchema.md)
 - [PaginatedResponseSchemaResourceAssemblySchemaSchema](docs/PaginatedResponseSchemaResourceAssemblySchemaSchema.md)
 - [PaginatedResponseSchemaResourceSchema](docs/PaginatedResponseSchemaResourceSchema.md)
 - [PaginatedResponseSchemaResourceSchemaSchema](docs/PaginatedResponseSchemaResourceSchemaSchema.md)
 - [PaginatedResponseSchemaUserSchema](docs/PaginatedResponseSchemaUserSchema.md)
 - [PermissionSchema](docs/PermissionSchema.md)
 - [PortCoordinate](docs/PortCoordinate.md)
 - [PortSchema](docs/PortSchema.md)
 - [ResourceAssemblySchemaComponentSchema](docs/ResourceAssemblySchemaComponentSchema.md)
 - [ResourceAssemblySchemaEnergyBankComponentSchema](docs/ResourceAssemblySchemaEnergyBankComponentSchema.md)
 - [ResourceAssemblySchemaEnergyBankConsumerSchema](docs/ResourceAssemblySchemaEnergyBankConsumerSchema.md)
 - [ResourceAssemblySchemaEnergyBankSchema](docs/ResourceAssemblySchemaEnergyBankSchema.md)
 - [ResourceAssemblySchemaRefuelSwapSchema](docs/ResourceAssemblySchemaRefuelSwapSchema.md)
 - [ResourceAssemblySchemaSchema](docs/ResourceAssemblySchemaSchema.md)
 - [ResourceSchema](docs/ResourceSchema.md)
 - [ResourceSchemaActionSchema](docs/ResourceSchemaActionSchema.md)
 - [ResourceSchemaActionSchemaSchema](docs/ResourceSchemaActionSchemaSchema.md)
 - [ResourceSchemaEnergyProfileSchema](docs/ResourceSchemaEnergyProfileSchema.md)
 - [ResourceSchemaSchema](docs/ResourceSchemaSchema.md)
 - [ResourceTypeEnum](docs/ResourceTypeEnum.md)
 - [SubnetSchema](docs/SubnetSchema.md)
 - [UserCreationSchema](docs/UserCreationSchema.md)
 - [UserSchema](docs/UserSchema.md)
 - [UserStatusEnum](docs/UserStatusEnum.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKeyCookie"></a>
### APIKeyCookie

- **Type**: API key
- **API key parameter name**: token
- **Location**: 

<a id="APIKeyHeader"></a>
### APIKeyHeader

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




